@@ -12,7 +12,7 @@ use namespace::autoclean;
 use File::Spec;
 use JSON::MaybeXS qw( encode_json );
 
-our $VERSION = 'v0.41.0'; # VERSION
+our $VERSION = '0.01';
 
 sub report {
     shift;
@@ -47,10 +47,6 @@ sub _get_file_coverage {
     my @coverage   = (undef);
 
     for my $i ( 1 .. $lines ) {
-        unless (defined $statements) {
-            push @coverage, undef;
-            next;
-        }
         my $statement = $statements->location($i);
         my $branch    = defined $branches ? $branches->location($i) : undef;
         push @coverage, _get_line_coverage( $statement, $branch );
@@ -94,7 +90,7 @@ sub _get_line_coverage {
         if $branch && !$branch->[0]->error;
     return $branch->[0]->covered . '/' . $branch->[0]->total if $branch;
     return $statement unless $statement;
-    return undef if $statement->[0]->uncoverable;
+    return if $statement->[0]->uncoverable;
     return $statement->[0]->covered;
 }
 
@@ -104,6 +100,18 @@ sub _get_line_coverage {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Devel::Cover::Report::Codecovbash - Generate a JSON file to be uploaded with the codecov bash script.
+
+=head1 VERSION
+
+version 0.01
+
 =head1 DESCRIPTION
 
 This is a coverage reporter for Codecov. It generates a JSON file that can be
@@ -113,46 +121,30 @@ L<https://docs.codecov.io/docs/about-the-codecov-bash-uploader> for details.
 The generated file will be named F<codecov.json> and will be in the
 F<cover_db> directory by default.
 
-Nearly all of the code in this distribution was simply copied from Pine
-Mizune's
-L<Devel-Cover-Report-Codecov|https://metacpan.org/release/Devel-Cover-Report-Codecov>
-distribution.
-
 =head1 UPLOADING RESULTS
 
 Use the codecov bash script:
 
     cover -report codecovbash
-    bash <(curl -s https://codecov.io/bash) -t token -f cover_db/codecov.json
+    bash < (curl -s https://codecov.io/bash) -t token -f cover_db/codecov.json
+
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/Devel-Cover-Report-Codecovbash/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
 =head1 SOURCE
 
-The source code repository for Devel-Cover-Report-Codecovbash can be found at
-L<https://github.com/perlpunk/Devel-Cover-Report-Codecovbash>.
+The source code repository for Devel-Cover-Report-Codecovbash can be found at L<https://github.com/houseabsolute/Devel-Cover-Report-Codecovbash>.
 
 =head1 AUTHOR
 
-Tina Müller <tinita@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=for stopwords Dave Rolsky Tina Müller
-
-=over 4
-
-=item *
-
 Dave Rolsky <autarch@urth.org>
 
-=item *
-
-Tina Müller <cpan2@tinita.de>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 - 2021 by Pine Mizune.
+This software is Copyright (c) 2019 by Pine Mizune.
 
 This is free software, licensed under:
 
